==> react-molecule-quick-action-1.2.0.tgz: package/lib/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var CLASS = 'sui-MoleculeQuickAction';
var SIZES = {
  MEDIUM: 'medium',
  LARGE: 'large'
};

var getClassName = function getClassName(variant) {
  return CLASS + "--" + variant;
};

var MoleculeQuickAction = function MoleculeQuickAction(_ref) {
  var _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size,
      children = _ref.children,
      leftIcon = _ref.leftIcon,
      rightIcon = _ref.rightIcon,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled;
  var sizeKey = size.toUpperCase();
  var isEnabled = disabled === false;
  var classNames = cx(CLASS, size && getClassName(SIZES[sizeKey]), disabled && getClassName('disabled'));

  var handleClick = function handleClick(ev) {
    return isEnabled && onClick(ev);
  };

  return React.createElement("div", {
    className: classNames,
    onClick: handleClick
  }, leftIcon && React.createElement("span", {
    className: CLASS + "-leftIcon"
  }, leftIcon), leftIcon || rightIcon ? React.createElement("span", {
    className: CLASS + "-text"
  }, children) : children, rightIcon && React.createElement("span", {
    className: CLASS + "-rightIcon"
  }, rightIcon));
};

MoleculeQuickAction.displayName = 'MoleculeQuickAction';
export { SIZES as moleculeQuickActionSizes };
export default MoleculeQuickAction;

==> react-molecule-quick-action-1.5.0.tgz: package/lib/index.js <==
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var CLASS = 'sui-MoleculeQuickAction';
var SIZES = {
  MEDIUM: 'medium',
  LARGE: 'large'
};

var getClassName = function getClassName(variant) {
  return CLASS + "--" + variant;
};

var MoleculeQuickAction = function MoleculeQuickAction(_ref) {
  var _ref$size = _ref.size,
      size = _ref$size === void 0 ? SIZES.MEDIUM : _ref$size,
      children = _ref.children,
      leftIcon = _ref.leftIcon,
      rightIcon = _ref.rightIcon,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled;
  var sizeKey = size.toUpperCase();
  var isEnabled = disabled === false;
  var classNames = cx(CLASS, size && getClassName(SIZES[sizeKey]), disabled && getClassName('disabled'));

  var handleClick = function handleClick(ev) {
    return isEnabled && onClick(ev);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classNames,
    onClick: handleClick
  }, leftIcon && /*#__PURE__*/React.createElement("span", {
    className: CLASS + "-leftIcon"
  }, leftIcon), leftIcon || rightIcon ? /*#__PURE__*/React.createElement("span", {
    className: CLASS + "-text"
  }, children) : children, rightIcon && /*#__PURE__*/React.createElement("span", {
    className: CLASS + "-rightIcon"
  }, rightIcon));
};

MoleculeQuickAction.displayName = 'MoleculeQuickAction';
export { SIZES as moleculeQuickActionSizes };
export default MoleculeQuickAction;
